# -*- coding: utf-8 -

page_meta = [
    {
        'url': 'flatpages:page',
        'title': '{{ flatpage.title }}',
        'title_uk': '{{ flatpage.title }}',
        'title_ru': '{{ flatpage.title }}',
        'title_en': '{{ flatpage.title }}',
        'keywords': '{{ flatpage.title }}',
        'keywords_uk': '{{ flatpage.title }}',
        'keywords_ru': '{{ flatpage.title }}',
        'keywords_en': '{{ flatpage.title }}',
        'description': '{{ flatpage.title }}',
        'description_uk': '{{ flatpage.title }}',
        'description_ru': '{{ flatpage.title }}',
        'description_en': '{{ flatpage.title }}',
        'breadcrumb': '{{ flatpage.title }}',
        'breadcrumb_uk': '{{ flatpage.title }}',
        'breadcrumb_ru': '{{ flatpage.title }}',
        'breadcrumb_en': '{{ flatpage.title }}',
        'header': '{{ flatpage.title }}',
        'header_uk': '{{ flatpage.title }}',
        'header_ru': '{{ flatpage.title }}',
        'header_en': '{{ flatpage.title }}'
    }
]
