{% extends 'base.html' %}


{% block meta_title %}
    {{ flatpage.title }}
{% endblock %}


{% block meta_description %}
    {{ flatpage.meta_d }}
{% endblock %}


{% block meta_keywords %}
    {{ flatpage.meta_d }}
{% endblock %}


{% block content %}
    <div class="container">
        {{ flatpage.content|safe }}
    </div>
{% endblock %}
